package com.bgy.sms.channel.bgy.service.impl;


import com.alibaba.fastjson.JSONObject;
import com.bgy.sms.channel.bgy.config.BgySMSConfig;
import com.bgy.sms.channel.bgy.dto.CLBizResponse;
import com.bgy.sms.channel.bgy.service.BgySmsService;
import com.bgy.sms.channel.bgy.utils.SendSmsUtil;
import com.bgy.sms.channel.dmHub.service.DmHubService;
import com.bgy.sms.config.ResponseCode;
import com.bgy.sms.service.SmsTemplateService;
import com.bgy.util.Md5Util;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;


@SuppressWarnings("DuplicatedCode")
@Service
public class BgySmsServiceImpl implements BgySmsService {

    private static final Logger log = LoggerFactory.getLogger(BgySmsServiceImpl.class);
    private static final String SUCCESS = "success";
    private static final String sendSuccessCode = "0";  // 发送响应成功字段
    private static final String createTemplateStatus = "status"; // 响应状态字段
    private static final String retMsg = "msg";                 //  响应描述
    private static final String createTemplateData = "data";    //  创建模板响应数据

    private static final String notificationId = "49"; // 碧桂园通知类短信ID
    private static final String marketingId = "52";    // 碧桂园营销类短信ID

    @Autowired
    private SmsTemplateService templateService;
    @Autowired
    private DmHubService dmHubService;

    @Override
    public CLBizResponse sendSms(String mobile, String content, String areaId) throws Exception {
        log.info("进入碧桂园短信发送接口");
        String appId = BgySMSConfig.appId;
//        String areaId = BgySMSConfig.areaId;
        String securityCode = BgySMSConfig.securityCode;
        String url = BgySMSConfig.url;
        String api = BgySMSConfig.api;
        Map<String, String> requestParams = new HashMap<>();
        requestParams.put("api", api);
        requestParams.put("appId", appId);
        requestParams.put("security", Md5Util.encrypt(appId + securityCode.toUpperCase()));
        requestParams.put("areaId", areaId);
        requestParams.put("content", content);
        requestParams.put("mobile", mobile);
        log.info("碧桂园短信接口参数：{}", requestParams);
        String retStr = SendSmsUtil.sendSmsByPost(url, JSONObject.toJSONString(requestParams));
        log.info("碧桂园短信接口返回信息：{}", retStr);
        if (retStr == null) {
            return new CLBizResponse(ResponseCode.UPSTREAM_BLANK);
        }
        JSONObject retJson = JSONObject.parseObject(retStr);
        String err = retJson.getString("err");
        String retPack = retJson.getString("package");
        String retCode = retJson.getString("ret");
        if (!sendSuccessCode.equals(retCode)) {
            if (err.contains("成功")) {
                return new CLBizResponse(ResponseCode.SUCCESS);
            }
            return new CLBizResponse(ResponseCode.UPSTREAM_FAIL.getCode(), err);
        } else {
            return new CLBizResponse(ResponseCode.SUCCESS);
        }
    }

}
